pref("scrapbook.ui.contextMenu", true);
pref("scrapbook.ui.contextSubMenu", false);
pref("scrapbook.ui.bookmarkMenu", true);
pref("scrapbook.ui.menuBar", true);
pref("scrapbook.ui.menuBar.icon", false);
pref("scrapbook.ui.toolsMenu", false);
pref("scrapbook.ui.statusBar", true);
pref("scrapbook.ui.folderList", "");
pref("scrapbook.ui.folderList.maxEntries", 5);
pref("scrapbook.tabs.open", false);
pref("scrapbook.tabs.openSource", false);
pref("scrapbook.tabs.combinedView", true);
pref("scrapbook.tabs.searchResult", true);
pref("scrapbook.tabs.note", false);
pref("scrapbook.data.default", true);
pref("scrapbook.data.path", "");
pref("scrapbook.data.title", "");
pref("scrapbook.detail.custom", "pdf, doc");
pref("scrapbook.multibook.enabled", false);
pref("scrapbook.note.fontsize", 16);
pref("scrapbook.note.linefeed", true);
pref("scrapbook.note.preview", false);
pref("scrapbook.trade.path", "");
pref("scrapbook.tree.unshift", false);
pref("scrapbook.tree.autoCollapse", false);
pref("scrapbook.confirmDelete", true);
pref("scrapbook.showDetailOnDrop", false);
pref("scrapbook.notifyOnComplete", true);
pref("scrapbook.key.menubar", "C");
pref("scrapbook.key.sidebar", "K");
pref("scrapbook.key.save", "");
pref("scrapbook.key.saveAs", "");
pref("scrapbook.key.saveAllTabs", "");
pref("scrapbook.key.bookmark", "");
